@@ -37,6 +37,7 @@ STREAM_GH_NEW_BUILD_RUNNERS_CG = os.getenv(
 )
 
 # host used to store the streams of events
+GH_TOKEN = os.getenv("GH_TOKEN", None)
 GH_REDIS_SERVER_HOST = os.getenv("GH_REDIS_SERVER_HOST", "localhost")
 GH_REDIS_SERVER_PORT = int(os.getenv("GH_REDIS_SERVER_PORT", "6379"))
 GH_REDIS_SERVER_AUTH = os.getenv("GH_REDIS_SERVER_AUTH", None)
@@ -51,7 +52,7 @@ DATASINK_RTS_PUSH = bool(os.getenv("DATASINK_PUSH_RTS", False))
 DATASINK_RTS_AUTH = os.getenv("DATASINK_RTS_AUTH", None)
 DATASINK_RTS_USER = os.getenv("DATASINK_RTS_USER", None)
 DATASINK_RTS_HOST = os.getenv("DATASINK_RTS_HOST", "localhost")
-DATASINK_RTS_PORT = os.getenv("DATASINK_RTS_PORT", 6379)
+DATASINK_RTS_PORT = int(os.getenv("DATASINK_RTS_PORT", "6379"))
 
 # logging related
 VERBOSE = os.getenv("VERBOSE", "1") == "0"
